@@ -29,11 +29,8 @@
 #include <gio/gio.h>
 
 #include "yelp-uri.h"
-#include "yelp-debug.h"
 #include "yelp-settings.h"
 
-static void           yelp_uri_class_init        (YelpUriClass   *klass);
-static void           yelp_uri_init              (YelpUri        *uri);
 static void           yelp_uri_dispose           (GObject        *object);
 static void           yelp_uri_finalize          (GObject        *object);
 
@@ -63,7 +60,7 @@ static void           resolve_gfile              (YelpUri        *uri,
 static gboolean       is_man_path                (const gchar    *uri,
                                                   const gchar    *encoding);
 
-G_DEFINE_TYPE (YelpUri, yelp_uri, G_TYPE_OBJECT);
+G_DEFINE_TYPE (YelpUri, yelp_uri, G_TYPE_OBJECT)
 #define GET_PRIV(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), YELP_TYPE_URI, YelpUriPrivate))
 
 typedef struct _YelpUriPrivate YelpUriPrivate;
@@ -308,7 +305,6 @@ resolve_start (YelpUri *uri)
 static void
 resolve_sync (YelpUri *uri)
 {
-    gchar *tmp;
     YelpUriPrivate *priv = GET_PRIV (uri);
 
     if (g_str_has_prefix (priv->res_arg, "ghelp:")
@@ -364,6 +360,9 @@ resolve_sync (YelpUri *uri)
         case YELP_URI_DOCUMENT_TYPE_EXTERNAL:
         case YELP_URI_DOCUMENT_TYPE_ERROR:
             break;
+        default:
+            g_assert_not_reached ();
+            break;
         }
     }
     else if (strchr (priv->res_arg, ':')) {
@@ -916,7 +915,8 @@ resolve_help_list_uri (YelpUri *uri)
 static gchar*
 find_man_path (gchar* name, gchar* section)
 {
-    gchar* argv[] = { "man", "-w", NULL, NULL, NULL };
+    const gchar* argv[] = { "man", "-w", NULL, NULL, NULL };
+    gchar **my_argv;
     gchar *ystdout = NULL;
     gint status;
     gchar **lines;
@@ -931,7 +931,10 @@ find_man_path (gchar* name, gchar* section)
         argv[2] = name;
     }
 
-    if (!g_spawn_sync (NULL, argv, NULL,
+    /* g_strdupv() should accept a "const gchar **". */
+    my_argv = g_strdupv ((gchar **) argv);
+
+    if (!g_spawn_sync (NULL, my_argv, NULL,
                        G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
                        NULL, NULL,
                        &ystdout, NULL, &status, &error)) {
@@ -940,6 +943,8 @@ find_man_path (gchar* name, gchar* section)
         g_error_free (error);
     }
 
+    g_strfreev (my_argv);
+
     if (status == 0) {
         lines = g_strsplit (ystdout, "\n", 2);
         g_free (ystdout);
@@ -994,10 +999,24 @@ resolve_man_uri (YelpUri *uri)
                         0, &match_info)) {
         /* The regexp didn't match, so treat as a file name. */
         gchar *newuri;
+        guint i;
+        static const char *man_suffixes[] = { "gz", "bz2", "lzma", NULL };
+
         priv->tmptype = YELP_URI_DOCUMENT_TYPE_MAN;
         newuri = g_strdup_printf ("file:%s", priv->res_arg + 4);
         g_free (priv->res_arg);
         priv->res_arg = newuri;
+        name = g_path_get_basename (newuri + 5);
+        for (i = 0; i < G_N_ELEMENTS (man_suffixes); i++) {
+            if (is_man_path (name, man_suffixes[i])) {
+                if (man_suffixes[i])
+                    name[strlen (name) - strlen (man_suffixes[i]) - 1] = '\0';
+                break;
+            }
+        }
+        priv->docuri = g_strdup ("man:");
+        priv->fulluri = g_strconcat ("man:", name, NULL);
+        priv->page_id = name;
         resolve_file_uri (uri);
     }
     else {
@@ -1055,12 +1074,43 @@ resolve_info_uri (YelpUri *uri)
     gint infopath_i, suffix_i;
 
     if (g_str_has_prefix (priv->res_arg, "info:/")) {
-        gchar *newuri;
+        gchar *newuri, *basename;
+        const gchar *hash;
+
         priv->tmptype = YELP_URI_DOCUMENT_TYPE_INFO;
         newuri = g_strdup_printf ("file:%s", priv->res_arg + 5);
         g_free (priv->res_arg);
         priv->res_arg = newuri;
+        basename = g_path_get_basename (newuri + 5);
+        hash = g_strrstr (basename, "#");
+        if (hash) {
+            name = g_strndup (basename, hash - basename);
+            sect = g_strdup (hash + 1);
+        } else {
+            name = g_strdup (basename);
+            sect = NULL;
+        }
+        g_free (basename);
+        for (suffix_i = 0; infosuffix[suffix_i]; suffix_i++) {
+            if (g_str_has_suffix (name, infosuffix[suffix_i])) {
+                name[strlen (name) - strlen (infosuffix[suffix_i])] = '\0';
+                break;
+            }
+        }
+
+        priv->docuri = g_strconcat ("info:", name, NULL);
+        if (sect) {
+            priv->fulluri = g_strconcat ("info:", name, "#", sect, NULL);
+            priv->page_id = g_strdup (sect);
+            priv->frag_id = sect;
+            sect = NULL; /* steal memory */
+        } else {
+            priv->fulluri = g_strdup (priv->docuri);
+        }
         resolve_file_uri (uri);
+
+        g_free (name);
+        g_free (sect);
         return;
     }
 
@@ -1186,7 +1236,10 @@ resolve_xref_uri (YelpUri *uri)
     }
     if (priv->page_id && priv->page_id[0] == '\0') {
         g_free (priv->page_id);
-        priv->page_id = NULL;
+        if (g_str_has_prefix (priv->docuri, "help:"))
+            priv->page_id = g_strdup ("index");
+        else
+            priv->page_id = NULL;
     }
 
     if (priv->page_id &&
